const projectFragment = `
  fragment Project on AppDonations_Project {
    id
    title
    categories
    donationsCount
    progressPercentage
    openAmountInCents
    picture {
      type
      url
      width
      height
    }
  }
`

export const projectsQuery = `
  ${projectFragment}

  query Projects($offset: Int, $limit: Int, $location: String) {
    appDonations_projects(offset: $offset, limit: $limit, location: $location) {
      totalResults
      data {
        ...Project
      }
    }
  }
`

const fullArticleFragment = `
  fragment FullArticle on AppGoodNews_GoodNewsArticle {
    id
    date
    headline
    teaserText
    pictureUrl
    pictureCredit
    articleUrl
    sortKey
    category
    language
    source
  }
`

export const goodNewsArticlesQuery = `
  ${fullArticleFragment}

  query GoodNewsArticles($lastDate: String) {
    appGoodNews_articles(lastDate: $lastDate) {
      articles {
        ...FullArticle
      }
      previousDateTeaser {
        ...FullArticle
      }
    }
  }
`

const fullEngagementFragment = `
  fragment FullEngagement on AppVolunteering_Engagement {
    id
    title
    description
    url
    imageUrl
    source
    categories
    organizer {
      name
      imageUrl
    }
    location
    latitude
    longitude
  }
`

export const volunteeringEngagementsQuery = `
  ${fullEngagementFragment}

  query VolunteeringEngagements($location: String, $category: String, $limit: Int!, $offset: Int!) {
    appVolunteering_engagements(location: $location, category: $category, limit: $limit, offset: $offset) {
      totalResults
      data {
        ...FullEngagement
      }
    }
  }
`

const fullUserAvatarFragment = `
  fragment FullUserAvatar on User {
    id
    identity
    avatar
    avatarBlurhash
    avatarLabel
    avatarDefaultColor
    fullName
    aboutMe
    pronouns
  }
`

export const lastInsightsQuery = `
  ${fullUserAvatarFragment}

  query LastInsights($offset: Int!, $limit: Int!)  {
    lastInsights(offset: $offset, limit: $limit) {
      data {
        id
        title
        description
        datePublished
        creator {
          ...FullUserAvatar
        }
        headerImage
        headerImageBlurhash
        topic {
          id
          title
        }
        numberOfPosts
        involvedUsers {
          totalResults
          data {
            ...FullUserAvatar
          }
        }
      }
      totalResults
    }
  }
`

export const featureTogglesQuery = `
  query FeatureToggles {
    featureToggles {
      name
      status
    }
  }
`

export const userSuggestionsQuery = `
  ${fullUserAvatarFragment}

  query UserSuggestions($limit: Int!) {
    userSuggestions(limit: $limit) {
      data {
        ...FullUserAvatar
      }
    }
  }
`
